/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Preparation of household data (00-0_households.do), 
* executed by data preparation master 00_preparation.do
*
* We extract the following information from the household-level data files
* - household split variable (to identify partners who separated households over waves)
* - wave variable (1 & 2)
*
* Produces data output in temporary folder: 
* - Wave 1: 00-0_households_wave1.dta
* - Wave 2: 00-0_households_wave2.dta
* 
**********************************************************************/
/*
Note: household identifier hhid is consistent and stable over waves. 
	It is the hhid that has been assigned to a respondent for the first time (e.g. hhid1 if respondent entered in wave 1)
	Except for a few cases where panel respondents move out of households, households can be merged over waves by hhid. 
	In case of move-outs of a panel respondent formerly living with an (eligible) partner, the household will be split 
	(marked by split==1 in wave 2).
	
	Hence, for longitudinal analyses of grandparent couples, split households should be removed. 

	For wave 2, this is indicated by 

	li hhid* if split==1, sepby(hhid)

  +-----------------------------------------+
  |        hhid         hhid1         hhid2 |
  |-----------------------------------------|
  | Bf-668138-A   Bf-668138-A   Bf-668138-A |
  | Bf-668138-A   Bf-668138-A   Bf-668138-B |
  |-----------------------------------------|
  | Bn-122336-A   Bn-122336-A   Bn-122336-A |
  | Bn-122336-A   Bn-122336-A   Bn-122336-B |
  |-----------------------------------------|
  | DK-989572-A   DK-989572-A   DK-989572-A |
  | DK-989572-A   DK-989572-A   DK-989572-B |
  |-----------------------------------------|
  | ES-375870-A   ES-375870-A   ES-375870-A |
  | ES-375870-A   ES-375870-A   ES-375870-B |
  +-----------------------------------------+
*/  

* loop over wave-specific files
foreach wave of numlist 1/2 {
* respondent file of wave `wave'
use "${wave`wave'}/sharew`wave'_${rel}_cv_h", clear
if `wave' == 1 {
	keep hhid1 hhid country waveid language
}
else { // wave 2
	keep hhid-split waveid language
}

* recode missing values
sharetom *, replace

* generate a simply wave identifier
gen wave = `wave' 

* save wave-specific data to temporary folder
save "${tempDir}/00-0_households_wave`wave'", replace

}

