/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Additional analyses not reported in the paper 
* (30-6_addon_further_analyses.do), executed by analysis master 30_analysis.do
* 
* Additional analyses comprise:
* - employment of grandmothers by countries
* - co-residence with / distance to grandchildren by countries
*
* Results from these additional analyses are not reported in the paper. 
*
**********************************************************************/

***********************************
* Percentage of grandmothers in 
* couples employed/working (age 50-65)
***********************************	   

use "${tempDir}/00-5_couple-child-dyads_wave1.dta", clear 

* select grandparental ties
keep if ch019_ > 0 & !mi(ch019_)

* Grandmothers of age 50-65
keep if inrange(gmage, 50,65)

* employed (incl. self-employed) 
gen gmempl = gmep005==2 if gmep005 < .

keep if gmempl < .

drop if country == 25
drop if country == 20

keep hhid gmempl country

replace gmempl = gmempl*100
tabstat gmempl, by(country) format(%9.1f)


recode country (13 18 = 1 "Nordic") (11 12 14 23 17 = 2 "Continental") (15 16 19 = 3 "Southern"), gen(class)

* Finally, with regard to labor force participation, about 51% of grandmothers are employed in the Nordic countries, 
* compared to 25% in continental countries and 13% southern countries
collapse (mean) gmempl , by(class country)
tabstat gmempl, by(class)


*************************************
* Distance to Grandchildren
* = distance to children with children
*************************************
use "${tempDir}/00-5_couple-child-dyads_wave1.dta", clear 

* select grandparental ties
keep if ch019_ > 0 & !mi(ch019_)

* 5802 grandparental couples
unique hhid

* Residential distance to grandchildren (all children with children)
clonevar d = ch007_

********************
* Coresidence
* percentage of grandparent couples living in the same building or HH with children and grandchildren
********************
gen help = inlist(ch007_,1,2) if ch007_ < .
bys hhid: egen cores = max(help)

replace cores = cores*100
preserve 
	keep hhid country cores
	duplicates drop hhid, force
	drop if country == 25
	drop if country == 20
	collapse (mean) cores, by(country)
	li
	recode country (13 18 = 1 "Nordic") (11 12 14 23 17 = 2 "Continental") (15 16 19 = 3 "Southern"), gen(class)
	tabstat cores, by(class)
restore
***********************


* Further analyses
gen closer24km = inlist(ch007_,1,2,3,4,5) if ch007_ < .
replace closer24km = closer24km*100
tabstat closer24km, by(country) format(%9.1f)


* distance to nearest child with child only
* select nearest child
bys hhid: egen nearest = min(ch007_)
lab val nearest ch007

bys hhid: gen first = _n==1
gen ncloser24km = inlist(nearest,1,2,3,4,5) if nearest < .
replace ncloser24km = ncloser24km*100
tabstat ncloser24km if first==1, by(country) format(%9.1f)





tabstat cores if first==1, by(country) format(%9.1f)

recode country (13 18 = 1 "north EU") (11 12 14 23 17 = 2 "middle EU") (15 16 19 = 3 "south EU"), gen(class)


/*
       1 in the same household
           2 in the same building
           3 less than 1 kilometre away
           4 between 1 and 5 kilometres away
           5 between 5 and 25 kilometres away
           6 between 25 and 100 kilometres away
           7 between 100 and 500 kilometres away
           8 more than 500 kilometres away
		   9 more than 500 kilometres away in another country
          

*/
keep country d
tab d, gen(d_)
collapse (mean) d_*, by(country)

reshape long d_, i(country) j(j)

by country (j), sort: gen D = sum(d_)

replace D = 100*D

format D %9.1f

lab def j ///
       1 "same hh" ///
       2 "same building" ///
       3 "< 1 km" ///
       4 "1-5 km" ///
       5 "5-25 km" ///
       6 "25-100 km" ///
       7 "100-500 km" ///
       8 "> 500 km" ///
	   9 "in another country", modify
	   
lab val j j


drop if country == 25
drop if country == 20

* southern countries
set scheme lean1
twoway (line D j  if country==19, lpat(shortdash)) ///
	   (line D j if country==16, lpat(shortdash)) ///
	   (line D j if country==15, lpat(shortdash) ) ///
	   (line D j  if country==11, lpat(solid)) ///
	   (line D j if country==23, lpat(solid)) ///
	   (line D j if country==17, lpat(solid)) ///
	   (line D j if country==12, lpat(solid)) ///
	   (line D j if country==14, lpat(dash)) ///
	   (line D j  if country==18, lpat(dash)) ///
	   (line D j if country==13, lpat(dash)), ///
	   legend( ///
		   lab(1 "Greece") ///
		   lab(2 "Italy") ///
		   lab(3 "Spain") ///
		   lab(4 "Austria") ///
		   lab(5 "Belgium") ///
		   lab(6 "France") ///
		   lab(7 "Germany") ///
		   lab(8 "Netherlands") ///
		   lab(9 "Denmark") ///
		   lab(10 "Sweden") ///
	   bplacement(seast) ring(0) cols(1) nobox region(lwidth(none) color(none) lcolor(none)) size(vsmall))  ///
	   xlabel(1(1)9, valuelabels angle(45)) xtitle("") ytitle("cumulative percentage") ///
	   ylabel(0 (25) 100, angle(0) format(%9.0f) grid glwidth(vvthin) glcolor(gs10)) ///
	   name(countries, replace) ///
	   xsize(10) ysize(10)

* classify countries
* North: Sweden, Denmark
* Middle: Germany, Austria, Belgium, the Netherlands, France
* South: Spain, Italy, Greece
recode country (13 18 = 1 "north EU") (11 12 14 23 17 = 2 "middle EU") (15 16 19 = 3 "south EU"), gen(class)

tabstat D if inlist(j,1,2), by(class)

collapse (mean) D, by(class j)


set scheme lean1
twoway (line D j  if class==1) ///
	   (line D j if class==2) ///
	   (line D j if class==3), ///
 legend( ///
		   lab(1 "Nordic") ///
		   lab(2 "Continental") ///
		   lab(3 "South") ///
		bplacement(seast) ring(0) cols(1) nobox region(lwidth(none) color(none) lcolor(none)) size(small))  ///
	   xlabel(1(1)9, labsize(small) valuelabels angle(45)) xtitle("") ytitle("cumulative percentage") ///
	   ylabel(0 (25) 100, labsize(small) angle(0) format(%9.0f) grid glwidth(vvthin) glcolor(gs10)) ///
	   name(groups, replace) ///
	   xsize(10) ysize(10) title("Distance to Grandchildren across European countries", size(medsmall))

	   



