/**********************************************************************
* Leopold, T. and Skopek, J. (2014). Gender and the Division of Labor 
* in Older Couples: How European Grandparents Share Market Work and 
* Childcare. In: Social Forces, published online 
* doi: 10.1093/sf/sou061
*
* Statistical analyses (30_analysis.do), 
* executed by _PROJECT_MASTER_.do
*
* This file runs the statistical analyses that are reported in the article
* as well as some additional analyses.
***********************************************************************/

run config
set more off

log using "${logDir}/analysis.smcl", smcl replace name(analysis)
log off analysis

/***************** MAIN ANALYSES *****************/

log on analysis
*********************************
* 30-1 descriptive analyses 
*	  (sample description, 
*	   Table 1, Table 2, 
*	   and Figure 1)
*********************************
do 30-1_description_gendergap.do

*********************************
* 30-2 OLS-Regression of grandfather's share (pooled models)
*	   (Model 1,2, and 4 in Table 3, Table 4, and Figure 2)
*********************************
do 30-2_pooled_regression_models.do

*********************************
* 30-3 Fixed-effects regression of grandfather's share
*	   (Model 3 in Table 3)
*********************************
do 30-3_fixed_effects_regression_model.do



/***************** ADDITIONAL ANALYSES *****************/

*********************************
* 30-4 Addon: Panel attrition from wave 1 to wave 2
*********************************
do 30-4_addon_panel_attrition.do

*********************************
* 30-5 Addon: Selectivity of the analytical sample
*	  Compare couples performing care with couples not performing care
*********************************
do 30-5_addon_selectivity_of_sample.do

*********************************
* 30-6 Further analyses (not reported)
*********************************
do 30-6_addon_further_analyses.do

log off analysis
log close analysis
